@@ -6,6 +6,27 @@ import numpy as np
 from ..core import plot_options as plotOptCore
 from ..core.serialization import register as serializationReg
 
+
+@serializationReg.registerForSerialization()
+class AnnotationsTextGeneric(plotOptCore.ObjectIterPlotOption):
+	""" Options containing details of various text annotations
+
+	Values should be iter of TextAnnotation objects (found in .annotations module)
+	"""
+	def __init__(self,name=None, value=None):
+		self.name = "annotationsTextGeneric"
+		self.value = value
+
+@serializationReg.registerForSerialization()
+class AnnotationsShadedGeneric(plotOptCore.ObjectIterPlotOption):
+	""" Options containing details of areas of the axis to shade
+
+	Values should be ShadedSliceAnnotation objects
+	"""
+	def __init__(self, name=None, value=None):
+		self.name = "annotationsShadedGeneric"
+		self.value = value
+
 @serializationReg.registerForSerialization()
 class AspectString(plotOptCore.StringPlotOption):
 	""" String controlling how the image aspect works
